package player

import (
	"blazing/logic/service/fight/info"
	"blazing/modules/blazing/model"
	"fmt"
)

type AI_player struct {
	baseplayer
	petinfo []model.PetInfo //精灵信息

	CanCapture bool
}


func (f *AI_player) SendPack(b []byte) error {
	return nil

}

func (f *AI_player) SendReadyToFightInfo(gg info.FightStartOutboundInfo) {

	fmt.Println(gg)
	//	f.FightC.UseSkill(f, f.fightinfo.OpponentPetList[0].SkillList[0].ID) //使用1#技能,实际上要按照四个技能权重去使用
	//这时候给个出招
}

func (f *AI_player) SendNoteReadyToFightInfo(fs info.NoteReadyToFightInfo) {
	fmt.Println(fs)
}

func (f *AI_player) SendFightEndInfo(_ info.FightOverInfo) {
	//fmt.Println("战斗结束")

}
func (f *AI_player) GetAction() {
	//使用1#技能,实际上要按照四个技能权重去使用
	f.FightC.UseSkill(f, int32(f.FightC.GetCurrPET(f).Skills[0].ID))
}
func (p *AI_player) End() {
	p.FightC = nil

	return
}

func (p *AI_player) GetPetInfo() []model.PetInfo {

	return p.petinfo
}
func (p *AI_player) SendAttackValue(info.AttackValueS) {

}
func (p *AI_player) SendChangePet(info.ChangePetInfo) {

}
