package common

import (
	"blazing/logic/service/fight/info"
	"blazing/modules/blazing/model"
)

type PlayerI interface {
	GetAction()
	GetPlayerCaptureContext() *info.PlayerCaptureContext
	Roll(int, int) (bool, float64, float64)
	SendPack(b []byte) error
	SendReadyToFightInfo(info.FightStartOutboundInfo)
	SendNoteReadyToFightInfo(info.NoteReadyToFightInfo)
	SendFightEndInfo(info.FightOverInfo)
	GetInfo() *model.PlayerInfo
	SendAttackValue(info.AttackValueS)
	SendChangePet(info.ChangePetInfo)
	SetFightC(FightI)
}
